Collisions, bumps, and jamming are prevented. | OiRA

Help

1. Προετοιμασία
2. Συμμετοχή των εργαζομένων
3. Αναγνώριση + Αξιολόγηση
   1. 1 Commercial manned guarding
      1. 1.1 Work environment (site related)
         1. 1.1.1 Slips, trips and falls are prevented.
         2. 1.1.2 Collisions, bumps, and jamming are prevented.
         3. 1.1.3 The electricity, gas and water supplies are in order and well-maintained.
         4. 1.1.4 Exposure to noise is prevented or controlled.
         5. 1.1.5 Exposure to chemical substances is prevented or controlled.
         6. 1.1.6 Exposure to biological substances is prevented or controlled.
         7. 1.1.7 Exposure to radiation is prevented or controlled.
         8. 1.1.8 Risks from ambient factors are prevented.
         9. 1.1.9 All necessary facilities are available and well maintained.
      2. 1.2 Fire prevention and emergency procedures
   2. Ω Πρόσθετοι κίνδυνοι (από το χρήστη)
   - Υπό εξέταση κίνδυνος
   - Κίνδυνος σε εκκρεμότητα
   - Ασφαλής κατάσταση
   - Προσοχή κίνδυνος!
4. Σχέδιο Δράσης
5. Έκθεση
6. Παρούσα Κατάσταση 0%

Help

## Collisions, bumps, and jamming are prevented.

Ναι Όχι Δεν ισχύει

Collisions, bumps, and jamming are not prevented.

Επιλέξτε την επικινδυνότητα για αυτόν τον κίνδυνο Χαμηλή Μέτρια Υψηλή

### Πληροφορίες

Collisions, bumps and jamming involve fixed objects (idle machinery, tools, furniture, …), or moving objects (machines placed in passageways, vehicles, sliding doors, …).

This is particularly important for static surveillance and rounds.

Check the following issues through visual inspection of work areas:

- The circulation of people and vehicles should be properly organised (sufficient clearance must be allowed between vehicle traffic routes and doors, gates, passages for pedestrians, corridors and staircases).
- Sufficient lighting should be provided (especially in stairwells and passageways).
- Warning indicators should be installed when the risk of collisions, bumps and getting jammed cannot be prevented through other measures. Make sure the client informs you (the private security services company) and the private security guards about the risks and measures in place.

### Πηγές Πληροφόρησης

#### Νομικές αναφορές και αναφορές πολιτικής

- 89/391/CEE Implementing measures to improve the health and safety of workers (framework directive).
- 89/654/EEC Directive on the minimum safety and health requirements for the workplace.

#### Πρόσθετο πληροφοριακό υλικό για την εκτίμηση του κινδύνου

- Lorem ipsum dolor sit.pdf
- Amet consectetuer.pdf

Σχόλια / Υφιστάμενα μέτρα (αν υπάρχουν)

Scroll to top
Back

## 2014-01-04-collisions-bumps-and-jamming-are-prevented.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More